#!/bin/bash
# Install script updated 2/9/2020

#Ensure there is a Version.txt
if [ -f Version.txt ]; then
    echo -e "Beginning install"
else
    echo -e "Missing Version.txt in the install package folder"
    echo -e "Please contact support@mo-sys.com for help with this"
    exit 1
fi

#Check the details of the Version.txt are compatible with the system
sw_for_atom=`grep -m 1 'Compilation Linux kernel =' ./Version.txt | grep -c 'upboard'`
if [[ $(uname -a | grep -c 'upboard') == $sw_for_atom ]]; then
  # all good
  echo -e "Platform matches"
else
  echo -e 'This software is for a different platform'
  echo -e "Please contact support@mo-sys.com for help with this"
  exit 1
fi


#Check Ubuntu version for this StarTracker variant
if [[ $(lsb_release -d | grep -c '20.04') == 1 ]]; then

   version=2004
   runtime="/home/martin/runtime"

   if [[ $(grep -c 'Compiled for pre-18.04 Ubuntu' ./Version.txt) == 1 ]]; then

      echo -e 'Version incompatibility: this software is for an older platform'
      echo -e "Please contact support@mo-sys.com for help with this"
      exit 1
   fi

elif [[ $(lsb_release -d | grep -c '14.04') == 1 ]]; then

   version=1404
   runtime="/home/martin/STracker/runtime"

   if [[ $(grep -c 'Compiled for Ubuntu 18.04-20.04' ./Version.txt) == 1 ]]; then

      echo -e 'Version incompatibility: this software is for a newer platform'
      echo -e "Please contact support@mo-sys.com for help with this"
      exit 1
   fi

else

   echo -e "Unknown Ubuntu version (expected 20.04 or 14.04):"
   lsb_release -d
   echo -e "Please contact support@mo-sys.com for help with this"
   exit 1

fi
echo -e "version: $version"


#Ensure the destination has a bin folder
if [ -d $runtime/bin ]
then
echo Found bin folder
else
echo "Could not find bin folder - aborting install"
exit 1
fi

#Ensure the destination has a lib folder
if [ -d $runtime/lib ]
then
echo Found lib folder
else
echo "Could not find lib folder - aborting install"
exit 1
fi


#Ensure the user is aware they will need a license file for the new s/w to work
#Ignore this check if the user has a license file with what appears to be a license key
#For now exploit the fact that license keys start with 0
if [[ -f $runtime/bin/license.cfg  &&  $(fgrep -c "= 0" $runtime/bin/license.cfg) == 1 ]]
then
    echo ""
else
	echo -e "The new software needs a license key to work (Error 36 if license invalid)"
	echo -e "You should only install this software if you have received a license,"
	echo -e "are prepared to wait for license help from Mo-Sys support"
	echo -e "or a Mo-Sys technician is standing by to help you install a license"
	echo -e ""
	echo -e "Do you still wish to proceed with the install? (y/n)"
	read
	if [[ "$REPLY" == "y" ]]; then
        echo ""
	else
		echo -e "Install aborted"
		exit 1;
	fi
fi


#Now we know bin/lib folders exist, check jsoncpp is installed
if [[ version != 2004  &&  $(locate libjsoncpp.so | head -c1 | wc -c) == 0 ]]; then

 echo -e "jsoncpp does not appear to be installed"
 echo -e "Updating cache to confirm - please wait..."
 echo -e "[Check README.txt file for password if asked for one]"
 echo 1234.com | sudo -S updatedb

 if [[ $(grep -c " / ext4 rw" /proc/mounts) == 1 ]]; then

   echo -e "jsoncpp not found! Install? (y/n) \c"
   read
   if [[ "$REPLY" == "y" ]]; then
      
	if [ -d ./jsoncpp0 ]
        then
	  cp -vbr ./jsoncpp0/* $runtime/lib
	  echo 1234.com | sudo -S ldconfig
          echo -e "Updating cache - pleae wait, this could take a few minutes..."
	  echo -e "[Check README.txt file for password if asked for one]"
	  echo 1234.com | sudo -S updatedb
        else
          echo -e "Could not find jsoncpp0 folder here - aborting install"
          exit 1
        fi

   else

	echo -e "jsonccp is required - aborting software install"
	exit 1

   fi

 else

   echo -e "Reboot in engineering mode and try again (json)"
   exit 1

 fi

fi


: '
#Ensure we can set scheduler & priority if we need to
if [[ $(getcap $runtime/bin/Stracker | grep -c '+ep') == 0 ]]; then

 if [[ $(grep -c " / ext4 rw" /proc/mounts) == 1 ]]; then

   #We are in Engineering mode - setcap
   echo 1234.com | sudo -S setcap cap_sys_nice+ep $runtime/bin/Stracker

 else

   echo -e "Reboot in engineering mode and try again (scheduler)"
   exit 1

 fi
fi
'


#Now we know bin/lib folders exist, check pistache is installed
if [[ version != 2004  &&  $(locate libpistache.so | head -c1 | wc -c) == 0 ]]; then

 echo -e "pistache does not appear to be installed"
 echo -e "Updating cache to confirm - please wait..."
 echo -e "[Check README.txt file for password if asked for one]"
 echo 1234.com | sudo -S updatedb

 if [[ $(grep -c " / ext4 rw" /proc/mounts) == 1 ]]; then

   echo -e "pistache not found! Install? (y/n) \c"
   read
   if [[ "$REPLY" == "y" ]]; then
      
	if [ -d ./pistache_lib ]
        then
	  cp -vbr ./pistache_lib/* $runtime/lib
	  echo 1234.com | sudo -S ldconfig
          echo -e "Updating cache - pleae wait, this could take a few minutes..."
	  echo -e "[Check README.txt file for password if asked for one]"
	  echo 1234.com | sudo -S updatedb
        else
          echo -e "Could not find pistache_lib folder here - aborting install"
          exit 1
        fi

   else

	echo -e "pistache is required - aborting software install"
	exit 1

   fi

 else

   echo -e "Reboot in engineering mode and try again (pistache)"
   exit 1

 fi

fi


#We know bin/lib folders exist, as does jsoncpp & pistache - check libblob_detector exists or Stracker won't start
if [[ version == 2004 || -f $runtime/lib/libblob_detector.so || -s $runtime/lib/libblob_detector.so ]]; then
 echo "Version 20.04 or found libblob_detector.so"
else

 echo -e "libblob_detector does not appear to be installed"
 echo -e "Updating cache to confirm - please wait..."
 echo -e "[Check README.txt file for password if asked for one]"
 echo 1234.com | sudo -S updatedb

 #We need to install libblob_detector - check it is here so it can be installed
 if [ -f ./libblob_detector.so ] && [ -s ./libblob_detector.so ]
 then
  echo "Found libblob_detector here as required to install"
 else
  echo "No libblob_detector here (required) - aborting install"
  echo "Contact support@mo-sys.com for this file"
  exit 1
 fi

 if [[ $(grep -c " / ext4 rw" /proc/mounts) == 1 ]]; then

   echo -e "libblob_detector not found! Install? (y/n) \c"
   read
   if [[ "$REPLY" == "y" ]]; then
      
	if [ -f ./libblob_detector.so ] && [ -s ./libblob_detector.so ]
        then

	  #First-time installation of libblob_detector.so
	  cp -v -b ./libblob_detector.so $runtime/lib/libblob_detector.so
	  echo 1234.com | sudo -S ldconfig
          echo -e "Updating cache - please wait, this could take a few minutes..."
	  echo 1234.com | sudo -S updatedb

        else
          echo -e "Could not find libblob_detector.so here - aborting install"
          exit 1
        fi

   else

	echo -e "libblob_detector.so is required - aborting software install"
	echo -e "Contact support@mo-sys.com for help"
	exit 1

   fi

 else

   #Need to be in engineering mode to update ldconfig database
   echo -e "Reboot in engineering mode and try again (blob detector)"
   exit 1

 fi

fi


#Check jsoncpp was successfully installed$(locate libjsoncpp.so | head -c1 | wc -c) != 0
if [[  version == 2004  ||  $(locate libjsoncpp.so | head -c1 | wc -c) == 0  ]]
then
   #For some reason the above could not install the missing libjsoncpp
   echo -e "jsoncpp needed but could not be installed - aborting"
   exit 1
fi

#Check libblob_detector was successfully installed
if [[  $(locate libblob_detector.so | head -c1 | wc -c) == 0  ]]
then
   #For some reason the above could not install the missing libblob_detector
   echo -e "libblob_detector needed but could not be installed - aborting"
   exit 1
fi



#Check the above part successfully installed libblob_detector/libjsoncpp (if relevant)
if [[ 1 ]]; then

   echo -e "jsoncpp & libblob_detector found - proceeding"
   
   #Do the install here!
   if [ -f ./Stracker ] && [ -s ./Stracker ]
   then
     echo Found Stracker
   else
     echo No Stracker
     exit 1
   fi

   echo "Copying files to destination bin and new folders and making executable..."

   cp -v -b ./libblob_detector.so $runtime/lib/libblob_detector.so
   cp -v -b ./Stracker       $runtime/bin/Stracker
   chmod +x $runtime/bin/Stracker

   if [ -d $runtime/new ]
   then
     echo Found new folder
   else
     echo Making new folder
     mkdir $runtime/new
   fi

   cp -v -b ./libblob_detector.so $runtime/new/libblob_detector.so
   cp -v -b ./Stracker       $runtime/new/Stracker
   chmod +x $runtime/new/Stracker

   #Copy default backup settings for this release
   cp -rv ./backup $runtime

   #Copy latest images
   cp -rv ./images $runtime

   echo "Installation SUCCESSFUL - finished"

fi
